package mi.hdm.mealPlan;

import mi.hdm.recipes.NutritionCalculator;
import mi.hdm.recipes.NutritionTable;
import mi.hdm.recipes.Recipe;
import mi.hdm.shoppingList.ShoppingList;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;

import java.time.LocalDate;
import java.util.HashMap;
import java.util.Map;

/**
 * Allow the user to create a meal plan for the week. The user can check out his nutrition scores for the week.
 */
public class MealPlan {
    private static final Logger log = LogManager.getLogger(MealPlan.class);
    private final Map<LocalDate, Recipe> plan;
    private static final MealPlan mealPlan = new MealPlan();

    private MealPlan () {
        plan = new HashMap<>();
    }

    public static MealPlan getInstance() {
        return mealPlan;
    }

    public void addRecipeToMealPlan(Recipe recipe, LocalDate date) {
        plan.put(date, recipe);
    }

    public void clear(LocalDate date) {
        log.info("Day {} cleared successfully.", date);
        plan.put(date, null);
    }

    public void clear() {
        log.info("MealPlan cleared successfully.");
        plan.clear();
    }

    public Recipe getRecipeForDay(LocalDate date) {


        return plan.get(date);
    }
    public Map<LocalDate, Recipe> getAllRecipesFromPlan () {
        return plan;
    }

    public NutritionTable getNutritionTable() {

        return NutritionCalculator.calculateNutritionTable(mealPlan);

    }

}
